@@ -139,7 +139,7 @@ class Client(object):
             dsn = os.environ['SENTRY_DSN']
 
         if dsn:
-            # TODO: should we validate other options werent sent?
+            # TODO: should we validate other options weren't sent?
             urlparts = urlparse(dsn)
             self.logger.debug(
                 "Configuring Raven for host: %s://%s:%s" % (urlparts.scheme,
@@ -226,7 +226,7 @@ class Client(object):
         """
         Returns a searchable string representing a message.
 
-        >>> result = client.process(**kwargs)
+        >>> result = client.capture(**kwargs)
         >>> ident = client.get_ident(result)
         """
         return '$'.join(result)
